/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
"use strict";
const tslib_1 = require("tslib");
const core_1 = require("@commerce-apps/core");
const lodash_1 = tslib_1.__importDefault(require("lodash"));
/**
 * Instantiate a Client object with desired ClientConfig to perform operations
 * available in this API client.
 *
 * Note: When performing operations that require ShopperJWT authentication, an
 * Authorization header containing a JWT can be added to the headers field of the
 * ClientConfig object. The Client will use that Authorization header for all the
 * operations it is used to perform.
 */
class Products extends core_1.BaseClient {
  constructor(config) {
    super(config);
    if (!!!config.baseUri) {
      this.clientConfig.baseUri =
        "https://{shortCode}.api.commercecloud.salesforce.com/product/products/v1";
    }
  }
  /**
   * Deletes the product by ID.
   */
  deleteProduct(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      productId: parameters["productId"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.delete({
      client: this,
      rawResponse: rawResponse,
      path: "/organizations/{organizationId}/products/{productId}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers
    });
  }
  /**
   * Action to get product information.
   */
  getProduct(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      productId: parameters["productId"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    queryParameters["siteId"] =
      queryParameters["siteId"] !== undefined
        ? parameters["siteId"]
        : this.clientConfig.parameters["siteId"];
    // @ts-ignore
    return core_1.StaticClient.get({
      client: this,
      rawResponse: rawResponse,
      path: "/organizations/{organizationId}/products/{productId}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers
    });
  }
  /**
    * Update a product using the information provided.

Fields that can be updated:
name, page_description, long_descripton, page_title,
page_keywords, brand, ean,upc, manufacture_sku,
manufacture_name, searchable, unit, searchable,
online_flag, default_variant_id.
    */
  updateProduct(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      productId: parameters["productId"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.patch({
      client: this,
      rawResponse: rawResponse,
      path: "/organizations/{organizationId}/products/{productId}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
   * Creates a product using the information provided. If a product with the same unique identifier exists, it will be cleaned and overwritten unless the header x-dw-validate-existing&#x3D;true is passed in with the request.
   */
  createProduct(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      productId: parameters["productId"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.put({
      client: this,
      rawResponse: rawResponse,
      path: "/organizations/{organizationId}/products/{productId}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
   * Searches product variations for master product or variation group product.\n \n The query attribute specifies a complex query that can be used to narrow down the search. This is the list\n of searchable attributes:\n \n id - String\n product_id - String\n name - String\n online - SiteSpecific Boolean\n in_stock - Boolean \n searchable - SiteSpecific Boolean \n ats - Actual available quantity to sell - Double \n variation_attribute.ATTRIBUTE_ID (Ex:variation_attribute.color) - String\n \n Sortable Fields:\n \n id - String\n product_id - String\n name - String\n online - SiteSpecific Boolean\n in_stock - Boolean \n searchable - SiteSpecific Boolean \n ats - Actual available quantity to sell - Double \n \n\n Note:\n The calculated value of \&quot;online\&quot; and \&quot;searchable\&quot; is used in the search/sort.\n A search/sort by the the site specific attributes require the Site ID query parameter to be set.\n They are \&quot;online\&quot;, \&quot;in_stock\&quot;, \&quot;searchable\&quot; and \&quot;ats\&quot;.\n  We assume that every field that starts with variation_attribute. is searchable and dot is followed by ATTRIBUTE_ID\&quot;.\n\n\n The list of expansions to retrieve product information. The expand values available are:\n \t\t  \n \t\t\t_base - Basic product information is retrieved. This expand is included by default.\n \t\t\tall - All product information including the following properties are retrieved:\n        \t\n        \t\timage\n        \t\tprice - siteId has to be provided to see this property\n        \t\tprice_currency - siteId has to be provided to see this property\n        \t\n \t\t\tavailability - Information related to the availability of the product variation.  This expand is not included by default.\n        \t\n        \t\tats - siteId has to be provided to see this property\n        \t\tin_stock - siteId has to be provided to see this property\n        \t\tonline - siteId has to be provided to see this property\n        \t\tsearchable\n        \t\n          variations - Information related to product variation is retrieved. This expand is included by default.\n \t\t\tattributes - Information related to product variation attributes is retrieved. This expand is not included by default.\n \t\t
   */
  searchProductVariations(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      productId: parameters["productId"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    queryParameters["siteId"] =
      queryParameters["siteId"] !== undefined
        ? parameters["siteId"]
        : this.clientConfig.parameters["siteId"];
    // @ts-ignore
    return core_1.StaticClient.post({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{productId}/variant-search",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
   * Reads variation groups for a product master.
   */
  getVariationGroupsForMasterProduct(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      masterProductId: parameters["masterProductId"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    queryParameters["siteId"] =
      queryParameters["siteId"] !== undefined
        ? parameters["siteId"]
        : this.clientConfig.parameters["siteId"];
    // @ts-ignore
    return core_1.StaticClient.get({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{masterProductId}/variation-groups",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers
    });
  }
  /**
    * Unassign a variation group product from a product master. The variation group product is not
  deleted: it remains as a normal product after unsassign.
    */
  unassignVariationGroupFromMasterProduct(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      masterProductId: parameters["masterProductId"],
      id: parameters["id"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.delete({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{masterProductId}/variation-groups/{id}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers
    });
  }
  /**
   * Read a variation group for a product master.
   */
  getVariationGroupForMasterProduct(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      masterProductId: parameters["masterProductId"],
      id: parameters["id"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    queryParameters["siteId"] =
      queryParameters["siteId"] !== undefined
        ? parameters["siteId"]
        : this.clientConfig.parameters["siteId"];
    // @ts-ignore
    return core_1.StaticClient.get({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{masterProductId}/variation-groups/{id}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers
    });
  }
  /**
   * Update a variation group for a product master.
   */
  updateVariationGroupForMasterProduct(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      masterProductId: parameters["masterProductId"],
      id: parameters["id"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.patch({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{masterProductId}/variation-groups/{id}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
    * Assign a variation group for a product master. If the variation group product does not initially exist,
  one is created using the body passed in.
    */
  assignVariationGroupToMasterProduct(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      masterProductId: parameters["masterProductId"],
      id: parameters["id"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.put({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{masterProductId}/variation-groups/{id}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
   * Reads variation for a product master.
   */
  getVariationsForMasterProduct(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      masterProductId: parameters["masterProductId"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    queryParameters["siteId"] =
      queryParameters["siteId"] !== undefined
        ? parameters["siteId"]
        : this.clientConfig.parameters["siteId"];
    // @ts-ignore
    return core_1.StaticClient.get({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{masterProductId}/variations",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers
    });
  }
  /**
    * Unassign a variation product from a product master.  The variation product is not deleted: it remains as a
  normal product after unsassign.
    */
  unassignVariationFromMasterProduct(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      masterProductId: parameters["masterProductId"],
      id: parameters["id"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.delete({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{masterProductId}/variations/{id}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers
    });
  }
  /**
   * Read a variation for a product master.
   */
  getVariationForMasterProduct(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      masterProductId: parameters["masterProductId"],
      id: parameters["id"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    queryParameters["siteId"] =
      queryParameters["siteId"] !== undefined
        ? parameters["siteId"]
        : this.clientConfig.parameters["siteId"];
    // @ts-ignore
    return core_1.StaticClient.get({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{masterProductId}/variations/{id}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers
    });
  }
  /**
   * Update a variation for a product master.
   */
  updateVariationForMasterProduct(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      masterProductId: parameters["masterProductId"],
      id: parameters["id"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.patch({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{masterProductId}/variations/{id}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
    * Assign a variation for a product master.  If the variation product does not initially exist,
  one is created using the body passed in.
    */
  assignVariationForMasterProduct(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      masterProductId: parameters["masterProductId"],
      id: parameters["id"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.put({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{masterProductId}/variations/{id}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
   * Read local and shared product options of a product.
   */
  getProductOptions(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      productId: parameters["productId"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.get({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{productId}/product-options",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers
    });
  }
  /**
   * Deletes a local product option or unbinds a shared product option from the product.
   */
  deleteProductOption(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      productId: parameters["productId"],
      id: parameters["id"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.delete({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{productId}/product-options/{id}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers
    });
  }
  /**
   * Read a local or shared product option of a product.
   */
  getProductOption(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      productId: parameters["productId"],
      id: parameters["id"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.get({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{productId}/product-options/{id}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers
    });
  }
  /**
   * Updates a local product option with the information provided.
   */
  updateProductOption(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      productId: parameters["productId"],
      id: parameters["id"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.patch({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{productId}/product-options/{id}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
   * Creates a local product option using the information provided or binds a shared product option to the product.
   */
  createProductOption(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      productId: parameters["productId"],
      id: parameters["id"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.put({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{productId}/product-options/{id}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
   * Deletes a local product option value by ID.
   */
  deleteProductOptionValue(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      id: parameters["id"],
      optionId: parameters["optionId"],
      productId: parameters["productId"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.delete({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{productId}/product-options/{optionId}/values/{id}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers
    });
  }
  /**
   * Read a local product option value of a local product option in a product.
   */
  getProductOptionValue(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      id: parameters["id"],
      optionId: parameters["optionId"],
      productId: parameters["productId"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.get({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{productId}/product-options/{optionId}/values/{id}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers
    });
  }
  /**
   * Updates a local product option value with the information provided.
   */
  updateProductOptionValue(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      id: parameters["id"],
      optionId: parameters["optionId"],
      productId: parameters["productId"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.patch({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{productId}/product-options/{optionId}/values/{id}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
   * Creates a local product option value using the information provided.
   */
  createProductOptionValue(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      id: parameters["id"],
      optionId: parameters["optionId"],
      productId: parameters["productId"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.put({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{productId}/product-options/{optionId}/values/{id}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
   * Action to get product variation attribute value information.
   */
  getVariationAttributeValue(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      productId: parameters["productId"],
      attributeId: parameters["attributeId"],
      id: parameters["id"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    queryParameters["siteId"] =
      queryParameters["siteId"] !== undefined
        ? parameters["siteId"]
        : this.clientConfig.parameters["siteId"];
    // @ts-ignore
    return core_1.StaticClient.get({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{productId}/variation-attributes/{attributeId}/values/{id}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers
    });
  }
  /**
   * Deletes the variation attribute value of a variation attribute bound to a master product.
   */
  deleteVariationAttributeValue(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      productId: parameters["productId"],
      attributeId: parameters["attributeId"],
      id: parameters["id"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.delete({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{productId}/variation-attributes/{attributeId}/values/{id}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers
    });
  }
  /**
   * Updates the variation attribute value of a variation attribute of a master product.
   */
  updateVariationAttributeValue(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      productId: parameters["productId"],
      attributeId: parameters["attributeId"],
      id: parameters["id"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.patch({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{productId}/variation-attributes/{attributeId}/values/{id}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
   * Action to create a product variation attribute value.
   */
  createVariationAttributeValue(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      productId: parameters["productId"],
      attributeId: parameters["attributeId"],
      id: parameters["id"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.put({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{productId}/variation-attributes/{attributeId}/values/{id}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
   * Reads variation attributes of a product of type variant, variation master, or variation group.
   */
  getVariationAttributes(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      productId: parameters["productId"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.get({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{productId}/variation-attributes",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers
    });
  }
  /**
   * Action to get variation attribute information only for master product.
   */
  getVariationAttribute(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      productId: parameters["productId"],
      id: parameters["id"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.get({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{productId}/variation-attributes/{id}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers
    });
  }
  /**
   * Deletes the variation attribute by ID.
   */
  deleteVariationAttribute(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      productId: parameters["productId"],
      id: parameters["id"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.delete({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{productId}/variation-attributes/{id}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers
    });
  }
  /**
    * Updates the variation attribute with the specified information.
  name
  slicing
  
    */
  updateVariationAttribute(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      productId: parameters["productId"],
      id: parameters["id"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.patch({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{productId}/variation-attributes/{id}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
   * Creates a variation attribute using the information provided.
   */
  createVariationAttribute(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"],
      productId: parameters["productId"],
      id: parameters["id"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.put({
      client: this,
      rawResponse: rawResponse,
      path:
        "/organizations/{organizationId}/products/{productId}/variation-attributes/{id}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
    * &quot;Searches for products.\n\n The query attribute specifies a complex query that can be used to narrow down the search. Attributes are grouped\n into different buckets.  These are the list of searchable attributes with their corresponding buckets:\n\n Main:\n \n    id - String\n    name - String\n    online - SiteSpecific Boolean\n    searchable - SiteSpecific Boolean \n    valid_from - SiteSpefic DateTime \n    valid_to - SiteSpecfic DateTime \n    type - ProductType \n    creation_date - DateTime\n \n Catalog:\n \n    catalog_id - String\n \n Category:\n \n    category_id - String\n \n Special:\n \n    type - {\&quot;item\&quot;, \&quot;set, \&quot;bundle\&quot;, \&quot;master\&quot;, \&quot;part_of_product_set\&quot;, \&quot;bundled\&quot;, \&quot;variant\&quot;, \&quot;variation_group\&quot;, \&quot;option\&quot;, \&quot;retail_set\&quot;, \&quot;part_of_retail_set\&quot;}\n \n\n The sortable properties are:\n \n id - String\n name - String\n creation_date - DateTime\n \n\n Note that catalog_id is the id of the catalog to which products are assigned to.\n\n Only attributes in the same bucket can be joined using a disjunction (OR).\n For instance, when joining id and catalog_id above, only a conjunction is allowed (AND), whereas id\n and searchable can be joined using a disjunction because they are in the same bucket.  If an attribute\n is used in a disjunction (OR) that violates this rule, an exception will be thrown.\n\n The product search retrieves additional properties of the product when expansions are used.\n\tThe available expand attribute values are:\n \n        \t&#x27;all&#x27; will retrieve all the product properties.\n          &#x27;availability&#x27; will retrieve the following properties:\n            ats\n            in_stock\n            online\n\t\t    \n          &#x27;categories&#x27; will retrieve the following properties:\n            assigned_categories\n\t\t\t\n          &#x27;images&#x27; will retrieve the following properties:\n            image\n\t\t\t\n\t\t\t&#x27;all_images&#x27; used with images will retrieve the following properties:\n            image\n            image_groups\n\t\t\t\n          &#x27;prices&#x27; will retrieve the following properties:\n            price\n            price_currency\n\t\t\t\n          &#x27;sets&#x27; will retrieve the following properties:\n            set_products\n            product_sets\n\t\t\t\n          &#x27;bundles&#x27; will retrieve the following properties:\n            product_bundles\n            bundled_products\n            \n\t\t\t\n\n &quot;

    */
  searchProducts(options, rawResponse) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId:
        parameters["organizationId"] !== undefined
          ? parameters["organizationId"]
          : this.clientConfig.parameters["organizationId"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    queryParameters["siteId"] =
      queryParameters["siteId"] !== undefined
        ? parameters["siteId"]
        : this.clientConfig.parameters["siteId"];
    // @ts-ignore
    return core_1.StaticClient.post({
      client: this,
      rawResponse: rawResponse,
      path: "/organizations/{organizationId}/product-search",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
}
module.exports = Products;
//# sourceMappingURL=products.js.map
